@@ -66,3 +66,9 @@ Base.prototype.ROYALE_REFLECTION_INFO = function () {
     }
   };
 };
+/**
+ * @export
+ * @const
+ * @type {number}
+ */
+Base.prototype.ROYALE_REFLECTION_INFO.compileFlags = 9;
